@@ -345,21 +345,40 @@ class Tile(Gtk.Button):
         else:
             self.installed_mark.clear()
 
-class PackageTile(Tile):
+class TileRow(Gtk.ListBoxRow):
+
+    def __init__(self, pkginfo, installer):
+        super(Gtk.ListBoxRow, self).__init__()
+        self.pkginfo = pkginfo
+        self.installed_mark = Gtk.Image()
+        self.installer = installer
+
+    def refresh_state(self):
+        self.installed = self.installer.pkginfo_is_installed(self.pkginfo)
+
+        if self.installed:
+            self.installed_mark.set_from_icon_name("emblem-installed", Gtk.IconSize.MENU)
+        else:
+            self.installed_mark.clear()
+
+class PackageRow(TileRow):
     def __init__(self, pkginfo, icon, summary, installer, review_info=None, more_info=None):
-        Tile.__init__(self, pkginfo, installer)
+        TileRow.__init__(self, pkginfo, installer)
 
         label_name = Gtk.Label(xalign=0)
 
+        display_name = self.installer.get_display_name(pkginfo)
+        display_name = GLib.markup_escape_text(display_name)
+
         if more_info:
-            label_name.set_markup("<b>%s (%s)</b>" % (self.installer.get_display_name(pkginfo), more_info))
+            more_info = GLib.markup_escape_text(more_info)
+            label_name.set_markup("<b>%s (%s)</b>" % (display_name, more_info))
         else:
-            label_name.set_markup("<b>%s</b>" % self.installer.get_display_name(pkginfo))
+            label_name.set_markup("<b>%s</b>" % display_name)
 
         label_name.set_justify(Gtk.Justification.LEFT)
-        label_summary = Gtk.Label()
-        label_summary.set_markup("<small>%s</small>" % summary)
-        label_summary.set_alignment(0.0, 0.0)
+        label_summary = Gtk.Label(xalign=0.0)
+        label_summary.set_markup("<small>%s</small>" % GLib.markup_escape_text(summary))
         label_summary.set_line_wrap(True)
 
         vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
@@ -378,6 +397,10 @@ class PackageTile(Tile):
         vbox.set_valign(Gtk.Align.CENTER)
 
         hbox = Gtk.Box()
+        hbox.set_margin_start(12)
+        hbox.set_margin_end(12)
+        hbox.set_margin_top(6)
+        hbox.set_margin_bottom(6)
         hbox.pack_start(icon, False, False, 0)
         hbox.pack_start(vbox, False, False, 0)
 
@@ -429,7 +452,9 @@ class VerticalPackageTile(Tile):
         Tile.__init__(self, pkginfo, installer)
 
         label_name = Gtk.Label(xalign=0.5)
-        label_name.set_markup("<b>%s</b>" % self.installer.get_display_name(pkginfo))
+
+        display_name = self.installer.get_display_name(pkginfo)
+        label_name.set_markup("<b>%s</b>" % GLib.markup_escape_text(display_name))
         vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=12)
         vbox.set_border_width(6)
 
@@ -471,11 +496,11 @@ class ReviewTile(Gtk.ListBoxRow):
         ratings_box.pack_start(stars_box, False, False, 0)
 
         label_name = Gtk.Label(xalign=0.0)
-        label_name.set_markup("<small>%s</small>" % username)
+        label_name.set_markup("<small>%s</small>" % GLib.markup_escape_text(username))
         ratings_box.pack_start(label_name, False, False, 0)
 
         label_date = Gtk.Label(xalign=0.0)
-        label_date.set_markup("<small>%s</small>" % date)
+        label_date.set_markup("<small>%s</small>" % GLib.markup_escape_text(date))
         ratings_box.pack_start(label_date, False, False, 0)
 
         label_comment = Gtk.Label(xalign=0.0)
@@ -513,10 +538,10 @@ class CategoryListBoxRow(Gtk.ListBoxRow):
         self.category = category
 
         if is_all:
-            label = Gtk.Label(_("All"), xalign=0, margin=10)
+            label = Gtk.Label(label=_("All"), xalign=0, margin=10)
             self.add(label)
         else:
-            label = Gtk.Label(category.name, xalign=0, margin=10)
+            label = Gtk.Label(label=category.name, xalign=0, margin=10)
             self.add(label)
 
 class Application(Gtk.Application):
@@ -536,7 +561,7 @@ class Application(Gtk.Application):
 
         self.low_res = self.get_low_res_screen()
 
-        self.settings = Gio.Settings("com.linuxmint.install")
+        self.settings = Gio.Settings(schema_id="com.linuxmint.install")
         self.arch = platform.machine()
 
         print("MintInstall: Detected system architecture: '%s'" % self.arch)
@@ -693,20 +718,19 @@ class Application(Gtk.Application):
 
     def get_low_res_screen(self):
         display = Gdk.Display.get_default()
-        screen = display.get_default_screen()
         pointer = display.get_default_seat().get_pointer()
+
+        height = 9999
+
         if pointer:
             position = pointer.get_position()
-            monitor_number = screen.get_monitor_at_point(position.x, position.y)
-        else:
-            monitor_number = 0
-        monitor = display.get_monitor(monitor_number)
-        height = monitor.get_geometry().height
+            monitor = display.get_monitor_at_point(position.x, position.y)
+            height = monitor.get_geometry().height
 
         # If it's less than our threshold than consider us 'low res'. The workarea being used is in
         # app pixels, so hidpi will also be affected here regardless of device resolution.
         if height < 768:
-            print("MintInstall: low resolution detected on monitor %d (%dpx height), limiting window height." % (monitor_number, height))
+            print("MintInstall: low resolution detected (%dpx height), limiting window height." % (height))
             return True
 
         return False
@@ -776,7 +800,7 @@ class Application(Gtk.Application):
         # Build the menu
         submenu = Gtk.Menu()
 
-        self.installed_menuitem = Gtk.MenuItem(_("Show installed applications"))
+        self.installed_menuitem = Gtk.MenuItem(label=_("Show installed applications"))
         self.installed_menuitem.connect("activate", self.show_installed_apps)
         self.installed_menuitem.show()
         submenu.append(self.installed_menuitem)
@@ -785,13 +809,13 @@ class Application(Gtk.Application):
         separator.show()
         submenu.append(separator)
 
-        search_summary_menuitem = Gtk.CheckMenuItem(_("Search in packages summary (slower search)"))
+        search_summary_menuitem = Gtk.CheckMenuItem(label=_("Search in packages summary (slower search)"))
         search_summary_menuitem.set_active(self.settings.get_boolean(SEARCH_IN_SUMMARY))
         search_summary_menuitem.connect("toggled", self.set_search_filter, SEARCH_IN_SUMMARY)
         search_summary_menuitem.show()
         submenu.append(search_summary_menuitem)
 
-        search_description_menuitem = Gtk.CheckMenuItem(_("Search in packages description (even slower search)"))
+        search_description_menuitem = Gtk.CheckMenuItem(label=_("Search in packages description (even slower search)"))
         search_description_menuitem.set_active(self.settings.get_boolean(SEARCH_IN_DESCRIPTION))
         search_description_menuitem.connect("toggled", self.set_search_filter, SEARCH_IN_DESCRIPTION)
         search_description_menuitem.show()
@@ -801,7 +825,7 @@ class Application(Gtk.Application):
         separator.show()
         submenu.append(separator)
 
-        self.refresh_cache_menuitem = Gtk.MenuItem(_("Refresh the list of packages"))
+        self.refresh_cache_menuitem = Gtk.MenuItem(label=_("Refresh the list of packages"))
         self.refresh_cache_menuitem.connect("activate", self.on_refresh_cache_clicked)
         self.refresh_cache_menuitem.show()
         self.refresh_cache_menuitem.set_sensitive(False)
@@ -811,7 +835,7 @@ class Application(Gtk.Application):
         separator.show()
         submenu.append(separator)
 
-        about_menuitem = Gtk.MenuItem(_("About"))
+        about_menuitem = Gtk.MenuItem(label=_("About"))
         about_menuitem.connect("activate", self.open_about)
         about_menuitem.show()
         submenu.append(about_menuitem)
@@ -819,22 +843,13 @@ class Application(Gtk.Application):
         menu_button = self.builder.get_object("menu_button")
         menu_button.connect("clicked", self.on_menu_button_clicked, submenu)
 
-        self.flowbox_applications = Gtk.FlowBox()
-        self.flowbox_applications.set_margin_start(6)
-        self.flowbox_applications.set_margin_end(6)
-        self.flowbox_applications.set_margin_top(6)
-        self.flowbox_applications.set_margin_bottom(6)
-        self.flowbox_applications.set_min_children_per_line(1)
-        self.flowbox_applications.set_max_children_per_line(1)
-        self.flowbox_applications.set_row_spacing(6)
-        self.flowbox_applications.set_column_spacing(6)
-        self.flowbox_applications.set_homogeneous(True)
-        self.flowbox_applications.set_valign(Gtk.Align.START)
-        self.flowbox_applications.connect("child-activated", self.on_flowbox_child_activated, self.PAGE_LIST)
-        self.flowbox_applications.connect("selected-children-changed", self.on_navigate_flowbox)
+        self.listbox_applications = Gtk.ListBox()
+        self.listbox_applications.connect("row-activated", self.on_app_row_activated, self.PAGE_LIST)
+        self.listbox_applications.connect("selected-rows-changed", self.on_navigate_listbox)
+        self.listbox_applications.set_header_func(list_header_func, None)
 
         box = self.builder.get_object("box_cat_page")
-        box.add(self.flowbox_applications)
+        box.add(self.listbox_applications)
 
         self.back_button = self.builder.get_object("back_button")
         self.back_button.connect("clicked", self.on_back_button_clicked)
@@ -894,16 +909,16 @@ class Application(Gtk.Application):
             self.sync_installed_apps()
             self.update_conditional_widgets()
 
-            GObject.idle_add(self.finished_loading_packages)
+            GLib.idle_add(self.finished_loading_packages)
 
             # Can take some time, don't block for it (these are categorizing packages based on apt info, not our listings)
-            GObject.idle_add(self.process_unmatched_packages)
+            GLib.idle_add(self.process_unmatched_packages)
 
             self.review_cache = reviews.ReviewCache()
             housekeeping.run()
         except GLib.Error as e:
             print("Loading error: %s", e.message)
-            GObject.idle_add(self.refresh_cache)
+            GLib.idle_add(self.refresh_cache)
 
     def load_featured_on_landing(self):
         box = self.builder.get_object("box_featured")
@@ -1029,12 +1044,6 @@ class Application(Gtk.Application):
             button.connect("clicked", self.category_button_clicked, category)
             flowbox.insert(button, -1)
 
-        # Add picks
-        button = Gtk.Button()
-        button.set_label(self.picks_category.name)
-        button.connect("clicked", self.category_button_clicked, self.picks_category)
-        flowbox.insert(button, -1)
-
         if self.installer.list_flatpak_remotes():
             # Add flatpaks
             button = Gtk.Button()
@@ -1043,6 +1052,11 @@ class Application(Gtk.Application):
 
             flowbox.insert(button, -1)
 
+        button = Gtk.Button()
+        button.set_label(self.all_category.name)
+        button.connect("clicked", self.category_button_clicked, self.all_category)
+        flowbox.insert(button, -1)
+
         box.pack_start(flowbox, True, True, 0)
         box.show_all()
 
@@ -1121,9 +1135,9 @@ class Application(Gtk.Application):
             if tile.pkginfo == pkginfo:
                 tile.refresh_state()
 
-        for fbchild in self.flowbox_applications.get_children():
+        for lschild in self.listbox_applications.get_children():
             try:
-                fbchild.get_child().refresh_state()
+                lschild.refresh_state()
             except Exception as e:
                 print(e)
 
@@ -1158,30 +1172,24 @@ class Application(Gtk.Application):
             installed_packages = self.settings.get_strv(INSTALLED_APPS)
             installed_packages = self.modernize_installed_list(installed_packages)
 
+        new_installed_packages = []
         for pkg_hash in installed_packages:
             try:
                 pkginfo = self.installer.cache[pkg_hash]
             except KeyError:
                 continue
 
-            if pkginfo:
-                if self.installer.pkginfo_is_installed(pkginfo):
-                    if pkginfo not in self.installed_category.pkginfos:
-                        self.installed_category.pkginfos.append(pkginfo)
-                else:
-                    installed_packages.remove(pkg_hash)
-                    try:
-                        self.installed_category.pkginfos.remove(pkginfo)
-                    except ValueError:
-                        pass
+            if self.installer.pkginfo_is_installed(pkginfo):
+                if pkginfo not in self.installed_category.pkginfos:
+                    self.installed_category.pkginfos.append(pkginfo)
+                new_installed_packages.append(pkg_hash)
             else:
-                installed_packages.remove(pkg_hash)
                 try:
                     self.installed_category.pkginfos.remove(pkginfo)
                 except ValueError:
                     pass
 
-        self.settings.set_strv(INSTALLED_APPS, installed_packages)
+        self.settings.set_strv(INSTALLED_APPS, new_installed_packages)
 
     def show_installed_apps(self, menuitem):
         self.show_category(self.installed_category)
@@ -1260,10 +1268,10 @@ class Application(Gtk.Application):
 
     def on_entry_text_changed(self, entry):
         if self.search_changed_timer > 0:
-            GObject.source_remove(self.search_changed_timer)
+            GLib.source_remove(self.search_changed_timer)
             self.search_changed_timer = 0
 
-        self.search_changed_timer = GObject.timeout_add(175, self.on_search_changed, entry)
+        self.search_changed_timer = GLib.timeout_add(175, self.on_search_changed, entry)
 
     def on_search_changed(self, searchentry):
         terms = searchentry.get_text()
@@ -1436,6 +1444,7 @@ class Application(Gtk.Application):
         self.active_tasks_category = Category(_("Currently working on the following packages"), None, None)
 
         self.picks_category = Category(_("Editors' Picks"), None, self.categories)
+
         edition = ""
         try:
             with open("/etc/linuxmint/info") as f:
@@ -1450,6 +1459,14 @@ class Application(Gtk.Application):
 
         self.flatpak_category = Category("Flatpak", None, self.categories)
 
+        # ALL
+        self.all_category = Category(_("All Applications"), None, self.categories)
+        with os.scandir("/usr/share/linuxmint/mintinstall/categories/") as it:
+            for entry in it:
+                if entry.path.endswith(".list"):
+                    self.all_category.matchingPackages.extend(self.file_to_array(entry.path))
+                    sorted(self.all_category.matchingPackages)
+
         # INTERNET
         category = Category(_("Internet"), None, self.categories)
 
@@ -1668,16 +1685,17 @@ class Application(Gtk.Application):
             return True
         return False
 
-    def reset_scroll_view(self, scrolledwindow, flowbox=None):
+    def reset_scroll_view(self, scrolledwindow, listbox=None):
         adjustment = scrolledwindow.get_vadjustment()
         adjustment.set_value(adjustment.get_lower())
 
-        if not flowbox:
+        if not listbox:
             return
 
         try:
-            first = flowbox.get_children()[0]
-            flowbox.select_child(first)
+            first = listbox.get_children()[0]
+            listbox.select_row(first)
+            first.grab_focus()
         except IndexError:
             pass
 
@@ -1706,7 +1724,7 @@ class Application(Gtk.Application):
             self.searchentry.set_text("")
             self.current_category = None
             if self.one_package_idle_timer > 0:
-                GObject.source_remove(self.one_package_idle_timer)
+                GLib.source_remove(self.one_package_idle_timer)
                 self.one_package_idle_timer = 0
 
         if self.previous_page == self.PAGE_LIST:
@@ -1718,8 +1736,8 @@ class Application(Gtk.Application):
                 self.show_active_tasks()
             else:
                 try:
-                    fc = self.flowbox_applications.get_selected_children()[0]
-                    fc.grab_focus()
+                    lr = self.listbox_applications.get_selected_rows()[0]
+                    lr.grab_focus()
                 except IndexError:
                     pass
 
@@ -1814,8 +1832,8 @@ class Application(Gtk.Application):
         self.stop_progress_pulse()
         self.current_pkginfo = None
 
-        for child in self.flowbox_applications.get_children():
-            self.flowbox_applications.remove(child)
+        for child in self.listbox_applications.get_children():
+            self.listbox_applications.remove(child)
 
         if self.subsearch_toggle.get_active()  \
             and self.current_category != None  \
@@ -1838,7 +1856,7 @@ class Application(Gtk.Application):
         searched_packages = []
 
         if self.search_idle_timer > 0:
-            GObject.source_remove(self.search_idle_timer)
+            GLib.source_remove(self.search_idle_timer)
             self.search_idle_timer = 0
 
         search_in_summary = self.settings.get_boolean(SEARCH_IN_SUMMARY)
@@ -1869,10 +1887,10 @@ class Application(Gtk.Application):
 
             self.search_idle_timer = 0
 
-            GObject.idle_add(self.on_search_results_complete, searched_packages)
+            GLib.idle_add(self.on_search_results_complete, searched_packages)
             return False
 
-        self.search_idle_timer = GObject.idle_add(idle_search_one_package, list(listing))
+        self.search_idle_timer = GLib.idle_add(idle_search_one_package, list(listing))
 
     def on_search_results_complete(self, results):
         self.clear_category_list()
@@ -1880,6 +1898,9 @@ class Application(Gtk.Application):
         self.builder.get_object("loading_spinner").stop()
         self.show_packages(results, from_search=True)
 
+    def on_app_row_activated(self, listbox, row, previous_page):
+        self.show_package(row.pkginfo, previous_page)
+
     def on_flowbox_item_clicked(self, tile, data=None):
         # This ties the GtkButton.clicked signal for the Tile class
         # to the flowbox mechanics.  Clicks would be handled by
@@ -1893,11 +1914,11 @@ class Application(Gtk.Application):
 
         self.show_package(child.get_child().pkginfo, previous_page)
 
-    def on_navigate_flowbox(self, box, data=None):
+    def on_navigate_listbox(self, box, data=None):
         sw = self.builder.get_object("scrolledwindow_applications")
 
         try:
-            selected = box.get_selected_children()[0]
+            selected = box.get_selected_rows()[0]
         except IndexError:
             return
 
@@ -1906,10 +1927,10 @@ class Application(Gtk.Application):
         sel_box = selected.get_allocation()
         sw_box = sw.get_allocation()
 
-        unit = sel_box.height + box.get_row_spacing()
+        unit = sel_box.height
 
         if (sel_box.y + unit) > (current + sw_box.height):
-            adj.set_value((sel_box.y + unit) - sw_box.height + box.get_row_spacing())
+            adj.set_value((sel_box.y + unit) - sw_box.height)
         elif sel_box.y < current:
             adj.set_value(sel_box.y)
 
@@ -1921,11 +1942,11 @@ class Application(Gtk.Application):
 
     def show_packages(self, pkginfos, from_search=False):
         if self.one_package_idle_timer > 0:
-            GObject.source_remove(self.one_package_idle_timer)
+            GLib.source_remove(self.one_package_idle_timer)
             self.one_package_idle_timer = 0
 
-        for child in self.flowbox_applications.get_children():
-            self.flowbox_applications.remove(child)
+        for child in self.listbox_applications.get_children():
+            self.listbox_applications.remove(child)
 
         self.category_tiles = []
         if len(pkginfos) == 0:
@@ -1994,11 +2015,11 @@ class Application(Gtk.Application):
         for bad in bad_ones:
             pkginfos.remove(bad)
 
-        self.one_package_idle_timer = GObject.idle_add(self.idle_show_one_package,
+        self.one_package_idle_timer = GLib.idle_add(self.idle_show_one_package,
                                                        pkginfos,
                                                        collisions)
 
-        self.flowbox_applications.show_all()
+        self.listbox_applications.show_all()
 
     def idle_show_one_package(self, pkginfos, collisions):
         try:
@@ -2024,23 +2045,21 @@ class Application(Gtk.Application):
             if pkginfo.pkg_hash.startswith("f"):
                 more_info = self.flatpak_remote_categories[pkginfo.remote].name
 
-        tile = PackageTile(pkginfo, icon, summary,
-                           installer=self.installer,
-                           review_info=review_info,
-                           more_info=more_info)
-        tile.connect("clicked", self.on_flowbox_item_clicked, pkginfo.pkg_hash)
+        tile = PackageRow(pkginfo, icon, summary,
+                          installer=self.installer,
+                          review_info=review_info,
+                          more_info=more_info)
 
-        box = Gtk.FlowBoxChild(child=tile)
-        box.show_all()
+        tile.show_all()
 
-        self.flowbox_applications.insert(box, -1)
+        self.listbox_applications.insert(tile, -1)
         self.category_tiles.append(tile)
 
         # Repeat until empty
         if len(pkginfos) > 0:
             return True
 
-        self.reset_scroll_view(self.builder.get_object("scrolledwindow_applications"), self.flowbox_applications)
+        self.reset_scroll_view(self.builder.get_object("scrolledwindow_applications"), self.listbox_applications)
         self.one_package_idle_timer = 0
         return False
 
@@ -2099,6 +2118,7 @@ class Application(Gtk.Application):
             homepage = None
         if homepage is not None and homepage != "":
             self.builder.get_object("website_link").show()
+            homepage = GLib.markup_escape_text(homepage)
             self.builder.get_object("website_link").set_markup("<a href='%s'>%s</a>" % (homepage, homepage))
         else:
             self.builder.get_object("website_link").hide()
@@ -2301,7 +2321,16 @@ class Application(Gtk.Application):
 
         if self.installer.pkginfo_is_installed(pkginfo):
             if pkginfo.pkg_hash.startswith("a"):
-                for desktop_file in ["/usr/share/applications/%s.desktop" % bin_name, "/usr/share/app-install/desktop/%s:%s.desktop" % (bin_name, bin_name)]:
+                for desktop_file in [
+                    # foo.desktop
+                    "/usr/share/applications/%s.desktop" % bin_name,
+                    # foo in foo-bar.desktop
+                    "/usr/share/applications/%s.desktop" % bin_name.split("-")[0],
+                    # foo in org.bar.Foo.desktop
+                    "/usr/share/applications/%s.desktop" % bin_name.split(".")[-1],
+                    "/usr/share/app-install/desktop/%s:%s.desktop" % (bin_name, bin_name)
+                    ]:
+
                     if os.path.exists(desktop_file):
                         config = configobj.ConfigObj(desktop_file)
                         try:
@@ -2351,7 +2380,7 @@ class Application(Gtk.Application):
             return
 
         self.builder.get_object("application_progress").pulse()
-        self.installer_pulse_timer = GObject.timeout_add(1050, self.installer_pulse_tick)
+        self.installer_pulse_timer = GLib.timeout_add(1050, self.installer_pulse_tick)
 
     def installer_pulse_tick(self):
         p = self.builder.get_object("application_progress")
@@ -2362,7 +2391,7 @@ class Application(Gtk.Application):
 
     def stop_progress_pulse(self):
         if self.installer_pulse_timer > 0:
-            GObject.source_remove(self.installer_pulse_timer)
+            GLib.source_remove(self.installer_pulse_timer)
             self.installer_pulse_timer = 0
 
 class DottedProgressLabel(Gtk.Fixed):
